"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _calculations = require("../../utils/calculations");

var _expoBlur = require("expo-blur");

var _MenuItem = _interopRequireDefault(require("./MenuItem"));

var _constants = require("../../constants");

var _styles = _interopRequireDefault(require("./styles"));

var _hooks = require("../../hooks");

var _validations = require("../../utils/validations");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const MenuContainerComponent = _constants.IS_IOS ? _expoBlur.BlurView : _reactNative.View;

const AnimatedView = _reactNativeReanimated.default.createAnimatedComponent(MenuContainerComponent);

const MenuListComponent = () => {
  const {
    state,
    theme,
    menuProps
  } = (0, _hooks.useInternal)();

  const [itemList, setItemList] = _react.default.useState([]);

  const menuHeight = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _calculations.calculateMenuHeight)(itemList.length), [itemList]);

  const leftOrRight = () => {
    'worklet';

    const anchorPositionHorizontal = menuProps.value.anchorPosition.split('-')[1];
    const itemWidth = menuProps.value.itemWidth;
    let style = {};
    anchorPositionHorizontal === 'right' ? style = {
      left: -_constants.MENU_WIDTH + itemWidth
    } : anchorPositionHorizontal === 'left' ? style = {
      left: 0
    } : style = {
      left: -menuProps.value.itemWidth - _constants.MENU_WIDTH / 2 + menuProps.value.itemWidth / 2
    };
    return style;
  };

  const messageStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const translate = (0, _calculations.menuAnimationAnchor)(menuProps.value.anchorPosition, menuProps.value.itemWidth, menuProps.value.items.length);

    const _leftOrRight = leftOrRight();

    const menuScaleAnimation = () => state.value === _constants.CONTEXT_MENU_STATE.ACTIVE ? (0, _reactNativeReanimated.withSpring)(1, _constants.SPRING_CONFIGURATION_MENU) : (0, _reactNativeReanimated.withTiming)(0, {
      duration: _constants.HOLD_ITEM_TRANSFORM_DURATION
    });

    const opacityAnimation = () => (0, _reactNativeReanimated.withTiming)(state.value === _constants.CONTEXT_MENU_STATE.ACTIVE ? 1 : 0, {
      duration: _constants.HOLD_ITEM_TRANSFORM_DURATION
    });

    return { ..._leftOrRight,
      height: menuHeight.value,
      opacity: opacityAnimation(),
      transform: [{
        translateX: translate.begginingTransformations.translateX
      }, {
        translateY: translate.begginingTransformations.translateY
      }, {
        scale: menuScaleAnimation()
      }, {
        translateX: translate.endingTransformations.translateX
      }, {
        translateY: translate.endingTransformations.translateY
      }]
    };
  });
  const animatedInnerContainerStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      backgroundColor: theme.value === 'light' ? 'rgba(255, 255, 255, .75)' : 'rgba(0,0,0,0.5)'
    };
  }, [theme]);
  const animatedProps = (0, _reactNativeReanimated.useAnimatedProps)(() => {
    return {
      blurType: theme.value
    };
  }, [theme]);

  const setter = items => {
    setItemList(items);
  };

  (0, _reactNativeReanimated.useAnimatedReaction)(() => menuProps.value.items, (_items, _prevItems) => {
    if (!(0, _validations.deepEqual)(_items, _prevItems)) {
      (0, _reactNativeReanimated.runOnJS)(setter)(_items);
    }
  }, [menuProps]);
  const renderItems = (0, _react.useMemo)(() => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, itemList && itemList.length > 0 ? itemList.map((item, index) => {
    return /*#__PURE__*/_react.default.createElement(_MenuItem.default, {
      key: index,
      item: item,
      isLast: itemList.length === index + 1
    });
  }) : null), [itemList]);
  return /*#__PURE__*/_react.default.createElement(AnimatedView // @ts-ignore
  , {
    intensity: 100,
    animatedProps: animatedProps,
    style: [_styles.default.menuContainer, messageStyles]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [{ ..._reactNative.StyleSheet.absoluteFillObject
    }, animatedInnerContainerStyle]
  }, renderItems));
};

const MenuList = /*#__PURE__*/_react.default.memo(MenuListComponent);

var _default = MenuList;
exports.default = _default;
//# sourceMappingURL=MenuList.js.map